@@ -16,7 +16,5 @@ pub fn copy_file_range<InFd: AsFd, OutFd: AsFd>(
     off_out: Option<&mut u64>,
     len: u64,
 ) -> io::Result<u64> {
-    let fd_in = fd_in.as_fd();
-    let fd_out = fd_out.as_fd();
-    imp::fs::syscalls::copy_file_range(fd_in, off_in, fd_out, off_out, len)
+    imp::fs::syscalls::copy_file_range(fd_in.as_fd(), off_in, fd_out.as_fd(), off_out, len)
 }
