@@ -35,9 +35,8 @@ use imp::fs::{FlockOperation, Mode};
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/lseek.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/lseek.2.html
 #[inline]
-pub fn seek<Fd: AsFd>(fd: &Fd, pos: SeekFrom) -> io::Result<u64> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::seek(fd, pos)
+pub fn seek<Fd: AsFd>(fd: Fd, pos: SeekFrom) -> io::Result<u64> {
+    imp::fs::syscalls::seek(fd.as_fd(), pos)
 }
 
 /// `lseek(fd, 0, SEEK_CUR)`—Returns the current position within a file.
@@ -53,9 +52,8 @@ pub fn seek<Fd: AsFd>(fd: &Fd, pos: SeekFrom) -> io::Result<u64> {
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/lseek.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/lseek.2.html
 #[inline]
-pub fn tell<Fd: AsFd>(fd: &Fd) -> io::Result<u64> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::tell(fd)
+pub fn tell<Fd: AsFd>(fd: Fd) -> io::Result<u64> {
+    imp::fs::syscalls::tell(fd.as_fd())
 }
 
 /// `fchmod(fd)`—Sets open file or directory permissions.
@@ -71,9 +69,8 @@ pub fn tell<Fd: AsFd>(fd: &Fd) -> io::Result<u64> {
 /// [Linux]: https://man7.org/linux/man-pages/man2/fchmod.2.html
 #[cfg(not(target_os = "wasi"))]
 #[inline]
-pub fn fchmod<Fd: AsFd>(fd: &Fd, mode: Mode) -> io::Result<()> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::fchmod(fd, mode)
+pub fn fchmod<Fd: AsFd>(fd: Fd, mode: Mode) -> io::Result<()> {
+    imp::fs::syscalls::fchmod(fd.as_fd(), mode)
 }
 
 /// `fchown(fd)`—Sets open file or directory ownership.
@@ -86,9 +83,8 @@ pub fn fchmod<Fd: AsFd>(fd: &Fd, mode: Mode) -> io::Result<()> {
 /// [Linux]: https://man7.org/linux/man-pages/man2/fchown.2.html
 #[cfg(not(target_os = "wasi"))]
 #[inline]
-pub fn fchown<Fd: AsFd>(fd: &Fd, owner: Uid, group: Gid) -> io::Result<()> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::fchown(fd, owner, group)
+pub fn fchown<Fd: AsFd>(fd: Fd, owner: Uid, group: Gid) -> io::Result<()> {
+    imp::fs::syscalls::fchown(fd.as_fd(), owner, group)
 }
 
 /// `fstat(fd)`—Queries metadata for an open file or directory.
@@ -105,9 +101,8 @@ pub fn fchown<Fd: AsFd>(fd: &Fd, owner: Uid, group: Gid) -> io::Result<()> {
 /// [`Mode::from_raw_mode`]: crate::fs::Mode::from_raw_mode
 /// [`FileType::from_raw_mode`]: crate::fs::FileType::from_raw_mode
 #[inline]
-pub fn fstat<Fd: AsFd>(fd: &Fd) -> io::Result<Stat> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::fstat(fd)
+pub fn fstat<Fd: AsFd>(fd: Fd) -> io::Result<Stat> {
+    imp::fs::syscalls::fstat(fd.as_fd())
 }
 
 /// `fstatfs(fd)`—Queries filesystem statistics for an open file or directory.
@@ -123,9 +118,8 @@ pub fn fstat<Fd: AsFd>(fd: &Fd) -> io::Result<Stat> {
     target_os = "wasi"
 )))] // not implemented in libc for netbsd yet
 #[inline]
-pub fn fstatfs<Fd: AsFd>(fd: &Fd) -> io::Result<StatFs> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::fstatfs(fd)
+pub fn fstatfs<Fd: AsFd>(fd: Fd) -> io::Result<StatFs> {
+    imp::fs::syscalls::fstatfs(fd.as_fd())
 }
 
 /// `futimens(fd, times)`—Sets timestamps for an open file or directory.
@@ -137,9 +131,8 @@ pub fn fstatfs<Fd: AsFd>(fd: &Fd) -> io::Result<StatFs> {
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/futimens.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/utimensat.2.html
 #[inline]
-pub fn futimens<Fd: AsFd>(fd: &Fd, times: &Timestamps) -> io::Result<()> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::futimens(fd, times)
+pub fn futimens<Fd: AsFd>(fd: Fd, times: &Timestamps) -> io::Result<()> {
+    imp::fs::syscalls::futimens(fd.as_fd(), times)
 }
 
 /// `fallocate(fd, mode, offset, len)`—Adjusts file allocation.
@@ -166,9 +159,8 @@ pub fn futimens<Fd: AsFd>(fd: &Fd, times: &Timestamps) -> io::Result<()> {
 )))] // not implemented in libc for netbsd yet
 #[inline]
 #[doc(alias = "posix_fallocate")]
-pub fn fallocate<Fd: AsFd>(fd: &Fd, mode: FallocateFlags, offset: u64, len: u64) -> io::Result<()> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::fallocate(fd, mode, offset, len)
+pub fn fallocate<Fd: AsFd>(fd: Fd, mode: FallocateFlags, offset: u64, len: u64) -> io::Result<()> {
+    imp::fs::syscalls::fallocate(fd.as_fd(), mode, offset, len)
 }
 
 /// `fcntl(fd, F_GETFL) & O_ACCMODE`
@@ -178,9 +170,8 @@ pub fn fallocate<Fd: AsFd>(fd: &Fd, mode: FallocateFlags, offset: u64, len: u64)
 /// example, it doesn't reflect whether sockets have been shut down; for
 /// general I/O handle support, use [`io::is_read_write`].
 #[inline]
-pub fn is_file_read_write<Fd: AsFd>(fd: &Fd) -> io::Result<(bool, bool)> {
-    let fd = fd.as_fd();
-    _is_file_read_write(fd)
+pub fn is_file_read_write<Fd: AsFd>(fd: Fd) -> io::Result<(bool, bool)> {
+    _is_file_read_write(fd.as_fd())
 }
 
 pub(crate) fn _is_file_read_write(fd: BorrowedFd<'_>) -> io::Result<(bool, bool)> {
@@ -221,9 +212,8 @@ pub(crate) fn _is_file_read_write(fd: BorrowedFd<'_>) -> io::Result<(bool, bool)
 /// [Linux]: https://man7.org/linux/man-pages/man2/fsync.2.html
 /// [`fcntl_fullfsync`]: https://docs.rs/rustix/*/x86_64-apple-darwin/rustix/fs/fn.fcntl_fullfsync.html
 #[inline]
-pub fn fsync<Fd: AsFd>(fd: &Fd) -> io::Result<()> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::fsync(fd)
+pub fn fsync<Fd: AsFd>(fd: Fd) -> io::Result<()> {
+    imp::fs::syscalls::fsync(fd.as_fd())
 }
 
 /// `fdatasync(fd)`—Ensures that file data is written to the underlying
@@ -242,9 +232,8 @@ pub fn fsync<Fd: AsFd>(fd: &Fd) -> io::Result<()> {
     target_os = "redox"
 )))]
 #[inline]
-pub fn fdatasync<Fd: AsFd>(fd: &Fd) -> io::Result<()> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::fdatasync(fd)
+pub fn fdatasync<Fd: AsFd>(fd: Fd) -> io::Result<()> {
+    imp::fs::syscalls::fdatasync(fd.as_fd())
 }
 
 /// `ftruncate(fd, length)`—Sets the length of a file.
@@ -256,9 +245,8 @@ pub fn fdatasync<Fd: AsFd>(fd: &Fd) -> io::Result<()> {
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/ftruncate.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/ftruncate.2.html
 #[inline]
-pub fn ftruncate<Fd: AsFd>(fd: &Fd, length: u64) -> io::Result<()> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::ftruncate(fd, length)
+pub fn ftruncate<Fd: AsFd>(fd: Fd, length: u64) -> io::Result<()> {
+    imp::fs::syscalls::ftruncate(fd.as_fd(), length)
 }
 
 /// `flock(fd, operation)`—Acquire or release an advisory lock on an open file.
@@ -269,7 +257,6 @@ pub fn ftruncate<Fd: AsFd>(fd: &Fd, length: u64) -> io::Result<()> {
 /// [Linux]: https://man7.org/linux/man-pages/man2/flock.2.html
 #[cfg(not(target_os = "wasi"))]
 #[inline]
-pub fn flock<Fd: AsFd>(fd: &Fd, operation: FlockOperation) -> io::Result<()> {
-    let fd = fd.as_fd();
-    imp::fs::syscalls::flock(fd, operation)
+pub fn flock<Fd: AsFd>(fd: Fd, operation: FlockOperation) -> io::Result<()> {
+    imp::fs::syscalls::flock(fd.as_fd(), operation)
 }
