@@ -5,6 +5,8 @@ use super::c;
 
 #[cfg(not(windows))]
 pub(crate) mod syscalls;
+#[cfg(not(target_os = "wasi"))]
+pub(crate) use auxv::clock_ticks_per_second;
 pub(crate) use auxv::page_size;
 #[cfg(any(
     all(target_os = "android", target_pointer_width = "64"),
@@ -37,5 +39,5 @@ pub(crate) use types::{raw_cpu_set_new, RawCpuSet, CPU_SETSIZE};
 #[cfg(any(target_os = "android", target_os = "linux"))]
 pub use types::{MembarrierCommand, RawCpuid};
 #[cfg(not(target_os = "wasi"))]
-pub use types::{RawGid, RawNonZeroPid, RawPid, RawUid, EXIT_SIGNALED_SIGABRT};
+pub use types::{RawGid, RawNonZeroPid, RawPid, RawUid, Signal, EXIT_SIGNALED_SIGABRT};
 pub use types::{EXIT_FAILURE, EXIT_SUCCESS};
