@@ -17,9 +17,8 @@ pub use imp::io::ReadWriteFlags;
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/read.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/read.2.html
 #[inline]
-pub fn read<Fd: AsFd>(fd: &Fd, buf: &mut [u8]) -> io::Result<usize> {
-    let fd = fd.as_fd();
-    imp::io::syscalls::read(fd, buf)
+pub fn read<Fd: AsFd>(fd: Fd, buf: &mut [u8]) -> io::Result<usize> {
+    imp::io::syscalls::read(fd.as_fd(), buf)
 }
 
 /// `write(fd, buf)`—Writes to a stream.
@@ -31,9 +30,8 @@ pub fn read<Fd: AsFd>(fd: &Fd, buf: &mut [u8]) -> io::Result<usize> {
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/write.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/write.2.html
 #[inline]
-pub fn write<Fd: AsFd>(fd: &Fd, buf: &[u8]) -> io::Result<usize> {
-    let fd = fd.as_fd();
-    imp::io::syscalls::write(fd, buf)
+pub fn write<Fd: AsFd>(fd: Fd, buf: &[u8]) -> io::Result<usize> {
+    imp::io::syscalls::write(fd.as_fd(), buf)
 }
 
 /// `pread(fd, buf, offset)`—Reads from a file at a given position.
@@ -45,9 +43,8 @@ pub fn write<Fd: AsFd>(fd: &Fd, buf: &[u8]) -> io::Result<usize> {
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/pread.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/pread.2.html
 #[inline]
-pub fn pread<Fd: AsFd>(fd: &Fd, buf: &mut [u8], offset: u64) -> io::Result<usize> {
-    let fd = fd.as_fd();
-    imp::io::syscalls::pread(fd, buf, offset)
+pub fn pread<Fd: AsFd>(fd: Fd, buf: &mut [u8], offset: u64) -> io::Result<usize> {
+    imp::io::syscalls::pread(fd.as_fd(), buf, offset)
 }
 
 /// `pwrite(fd, bufs)`—Writes to a file at a given position.
@@ -59,9 +56,8 @@ pub fn pread<Fd: AsFd>(fd: &Fd, buf: &mut [u8], offset: u64) -> io::Result<usize
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/pwrite.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/pwrite.2.html
 #[inline]
-pub fn pwrite<Fd: AsFd>(fd: &Fd, buf: &[u8], offset: u64) -> io::Result<usize> {
-    let fd = fd.as_fd();
-    imp::io::syscalls::pwrite(fd, buf, offset)
+pub fn pwrite<Fd: AsFd>(fd: Fd, buf: &[u8], offset: u64) -> io::Result<usize> {
+    imp::io::syscalls::pwrite(fd.as_fd(), buf, offset)
 }
 
 /// `readv(fd, bufs)`—Reads from a stream into multiple buffers.
@@ -73,9 +69,8 @@ pub fn pwrite<Fd: AsFd>(fd: &Fd, buf: &[u8], offset: u64) -> io::Result<usize> {
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/readv.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/readv.2.html
 #[inline]
-pub fn readv<Fd: AsFd>(fd: &Fd, bufs: &mut [IoSliceMut<'_>]) -> io::Result<usize> {
-    let fd = fd.as_fd();
-    imp::io::syscalls::readv(fd, bufs)
+pub fn readv<Fd: AsFd>(fd: Fd, bufs: &mut [IoSliceMut<'_>]) -> io::Result<usize> {
+    imp::io::syscalls::readv(fd.as_fd(), bufs)
 }
 
 /// `writev(fd, bufs)`—Writes to a stream from multiple buffers.
@@ -87,9 +82,8 @@ pub fn readv<Fd: AsFd>(fd: &Fd, bufs: &mut [IoSliceMut<'_>]) -> io::Result<usize
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/writev.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/writev.2.html
 #[inline]
-pub fn writev<Fd: AsFd>(fd: &Fd, bufs: &[IoSlice<'_>]) -> io::Result<usize> {
-    let fd = fd.as_fd();
-    imp::io::syscalls::writev(fd, bufs)
+pub fn writev<Fd: AsFd>(fd: Fd, bufs: &[IoSlice<'_>]) -> io::Result<usize> {
+    imp::io::syscalls::writev(fd.as_fd(), bufs)
 }
 
 /// `preadv(fd, bufs, offset)`—Reads from a file at a given position into
@@ -101,9 +95,8 @@ pub fn writev<Fd: AsFd>(fd: &Fd, bufs: &[IoSlice<'_>]) -> io::Result<usize> {
 /// [Linux]: https://man7.org/linux/man-pages/man2/preadv.2.html
 #[cfg(not(target_os = "redox"))]
 #[inline]
-pub fn preadv<Fd: AsFd>(fd: &Fd, bufs: &mut [IoSliceMut<'_>], offset: u64) -> io::Result<usize> {
-    let fd = fd.as_fd();
-    imp::io::syscalls::preadv(fd, bufs, offset)
+pub fn preadv<Fd: AsFd>(fd: Fd, bufs: &mut [IoSliceMut<'_>], offset: u64) -> io::Result<usize> {
+    imp::io::syscalls::preadv(fd.as_fd(), bufs, offset)
 }
 
 /// `pwritev(fd, bufs, offset)`—Writes to a file at a given position from
@@ -115,9 +108,8 @@ pub fn preadv<Fd: AsFd>(fd: &Fd, bufs: &mut [IoSliceMut<'_>], offset: u64) -> io
 /// [Linux]: https://man7.org/linux/man-pages/man2/pwritev.2.html
 #[cfg(not(target_os = "redox"))]
 #[inline]
-pub fn pwritev<Fd: AsFd>(fd: &Fd, bufs: &[IoSlice<'_>], offset: u64) -> io::Result<usize> {
-    let fd = fd.as_fd();
-    imp::io::syscalls::pwritev(fd, bufs, offset)
+pub fn pwritev<Fd: AsFd>(fd: Fd, bufs: &[IoSlice<'_>], offset: u64) -> io::Result<usize> {
+    imp::io::syscalls::pwritev(fd.as_fd(), bufs, offset)
 }
 
 /// `preadv2(fd, bufs, offset, flags)`—Reads data, with several options.
@@ -131,13 +123,12 @@ pub fn pwritev<Fd: AsFd>(fd: &Fd, bufs: &[IoSlice<'_>], offset: u64) -> io::Resu
 #[cfg(any(linux_raw, all(libc, any(target_os = "android", target_os = "linux"))))]
 #[inline]
 pub fn preadv2<Fd: AsFd>(
-    fd: &Fd,
+    fd: Fd,
     bufs: &mut [IoSliceMut<'_>],
     offset: u64,
     flags: ReadWriteFlags,
 ) -> io::Result<usize> {
-    let fd = fd.as_fd();
-    imp::io::syscalls::preadv2(fd, bufs, offset, flags)
+    imp::io::syscalls::preadv2(fd.as_fd(), bufs, offset, flags)
 }
 
 /// `pwritev2(fd, bufs, offset, flags)`—Writes data, with several options.
@@ -151,11 +142,10 @@ pub fn preadv2<Fd: AsFd>(
 #[cfg(any(linux_raw, all(libc, any(target_os = "android", target_os = "linux"))))]
 #[inline]
 pub fn pwritev2<Fd: AsFd>(
-    fd: &Fd,
+    fd: Fd,
     bufs: &[IoSlice<'_>],
     offset: u64,
     flags: ReadWriteFlags,
 ) -> io::Result<usize> {
-    let fd = fd.as_fd();
-    imp::io::syscalls::pwritev2(fd, bufs, offset, flags)
+    imp::io::syscalls::pwritev2(fd.as_fd(), bufs, offset, flags)
 }
